@@ -47,12 +47,12 @@ class Audit(models.Model):
 
     def save(self, *args, **kwargs):
         user = get_current_user()
-        if self.created_at is None and not user.is_anonymous:
-            self.created_by = user
-            self.modified_by = user
-        elif not user.is_anonymous:
-            self.modified_by = user
-
+        if user:
+            if self.created_at is None and not user.is_anonymous:
+                self.created_by = user
+                self.modified_by = user
+            elif not user.is_anonymous:
+                self.modified_by = user
         super(Audit, self).save(*args, **kwargs)
 
 class City(Audit):
@@ -93,7 +93,7 @@ class City(Audit):
         ("Bogotá d C.", "Bogotá d C."),
     )
     name = models.CharField(_('name'), max_length=100)
-    state = models.CharField(_('state'), max_length=100, choices=STATES)
+    state = models.CharField(_('departament'), max_length=100, choices=STATES)
 
     class Meta:
         verbose_name = _('city')
